PEP: 373 Title: Python 2.7 Release Schedule Version: $Revision$
Last-Modified: $Date$ Author: Benjamin Peterson <benjamin@python.org>
Status: Final Type: Informational Content-Type: text/x-rst Created:
3-Nov-2008 Python-Version: 2.7

Abstract
========

This document describes the development and release schedule for Python
2.7.

Python 2.7 is the end of the Python 2.x series, and is succeeded by
Python 3. See
`the "Sunsetting Python 2" FAQ on python.org <https://www.python.org/doc/sunset-python-2/>`\_
for a general overview.

Update (April 2014)
===================

The End Of Life date (EOL, sunset date) for Python 2.7 has been moved
five years into the future, to 2020. This decision was made to clarify
the status of Python 2.7 and relieve worries for those users who cannot
yet migrate to Python 3. See also PEP 466.

This declaration does not guarantee that bugfix releases will be made on
a regular basis, but it should enable volunteers who want to contribute
bugfixes for Python 2.7 and it should satisfy vendors who still have to
support Python 2 for years to come.

There will be no Python 2.8 (see PEP 404).

Release Manager and Crew
========================

============================ ================== Position Name
============================ ================== 2.7 Release Manager
Benjamin Peterson Windows installers Steve Dower Mac installers Ned
Deily ============================ ==================

Maintenance releases
====================

Being the last of the 2.x series, 2.7 received bugfix support until
2020. Support officially stopped January 1 2020, and 2.7.18 code freeze
occurred on January 1 2020, but the final release occurred after that
date.

Dates of previous maintenance releases:

-   2.7.1 2010-11-27
-   2.7.2 2011-07-21
-   2.7.3rc1 2012-02-23
-   2.7.3rc2 2012-03-15
-   2.7.3 2012-03-09
-   2.7.4rc1 2013-03-23
-   2.7.4 2013-04-06
-   2.7.5 2013-05-12
-   2.7.6rc1 2013-10-26
-   2.7.6 2013-11-10
-   2.7.7rc1 2014-05-17
-   2.7.7 2014-05-31
-   2.7.8 2014-06-30
-   2.7.9rc1 2014-11-26
-   2.7.9 2014-12-10
-   2.7.10rc1 2015-05-09
-   2.7.10 2015-05-23
-   2.7.11rc1 2015-11-21
-   2.7.11 2015-12-05
-   2.7.12 2016-06-25
-   2.7.13rc1 2016-12-03
-   2.7.13 2016-12-17
-   2.7.14rc1 2017-08-26
-   2.7.14 2017-09-16
-   2.7.15rc1 2018-04-14
-   2.7.15 2018-05-01
-   2.7.16rc 2019-02-16
-   2.7.16 2019-03-02
-   2.7.17rc1 2019-10-05
-   2.7.17 2019-10-19
-   2.7.18rc1 2020-04-04
-   2.7.18 2020-04-20

2.7.0 Release Schedule
======================

The release schedule for 2.7.0 was:

-   2.7 alpha 1 2009-12-05
-   2.7 alpha 2 2010-01-09
-   2.7 alpha 3 2010-02-06
-   2.7 alpha 4 2010-03-06
-   2.7 beta 1 2010-04-03
-   2.7 beta 2 2010-05-08
-   2.7 rc1 2010-06-05
-   2.7 rc2 2010-06-19
-   2.7 final 2010-07-03

Possible features for 2.7
=========================

Nothing here. \[Note that a moratorium on core language changes is in
effect.\]

References
==========

-   `"The Python 2 death march" on python-dev <https://mail.python.org/archives/list/python-dev@python.org/thread/APWHFYQDKNVYQAK3HZMBGQIZHAVRHCV2/>`\_
-   `Petition: abandon plans to ship a 2.7.18 in April <https://discuss.python.org/t/petition-abandon-plans-to-ship-a-2-7-18-in-april/2946/>`\_
-   `[RELEASE] Python 2.7.18, the end of an era <https://mail.python.org/archives/list/python-announce-list@python.org/thread/OFCIETIXLX34X7FVK5B5WPZH22HXV342/>`\_

Copyright
=========

This document has been placed in the public domain.

 .. Local Variables: mode: indented-text indent-tabs-mode: nil
sentence-end-double-space: t fill-column: 70 coding: utf-8 End:
